@@ -1,19 +1,17 @@
 
 """
-
-  ____       _ ____  _ _         _____ _____ ____  __  __ _ _         _____           _ _    _ _
- / ___|  ___(_) __ )(_) |_ ___  |_   _| ____|  _ \|  \/  (_) |_ ___  |_   _|__   ___ | | | _(_) |_
- \___ \ / __| |  _ \| | __/ _ \   | | |  _| | |_) | |\/| | | __/ _ \   | |/ _ \ / _ \| | |/ / | __|
-  ___) | (__| | |_) | | ||  __/   | | | |___|  _ <| |  | | | ||  __/   | | (_) | (_) | |   <| | |_
- |____/ \___|_|____/|_|\__\___|   |_| |_____|_| \_\_|  |_|_|\__\___|   |_|\___/ \___/|_|_|\_\_|\__|
-
+  ____       _ ____  _ _         _____           _ _    _ _
+ / ___|  ___(_) __ )(_) |_ ___  |_   _|__   ___ | | | _(_) |_
+ \___ \ / __| |  _ \| | __/ _ \   | |/ _ \ / _ \| | |/ / | __|
+  ___) | (__| | |_) | | ||  __/   | | (_) | (_) | |   <| | |_
+ |____/ \___|_|____/|_|\__\___|   |_|\___/ \___/|_|_|\_\_|\__|
 
 SearchRequestBuilder- make requests to the Scibite Search API and process results.
 
 """
 
 __author__ = 'SciBite DataScience'
-__version__ = '0.5.0'
+__version__ = '0.5.4'
 __copyright__ = '(c) 2022, SciBite Ltd'
 __license__ = 'Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License'
 
@@ -64,7 +62,7 @@ class SBSRequestBuilder():
         """
         self.url = url.rstrip('/')
         
-    def get_docs(self,query ='',markup=True, limit = 20,offset = 0):
+    def get_docs(self,query ='', markup=True, limit = 20,offset = 0, additional_fields=[]):
         """This endpoint allows searching and retrieval of documents. 
 		:query: SSQL query
 		:markup: Whether annotated text should markup the entities
@@ -74,6 +72,8 @@ class SBSRequestBuilder():
         options ={"markup":markup,"limit":limit, "offset":offset}
         if query:
             options["queries"]=query
+        if additional_fields:
+            options["fields"]=additional_fields
 
         req = requests.get(self.url+"/api/search/v1/documents",params = options, headers = self.headers,verify=self.verify_request)
         return req.json()
@@ -86,6 +86,8 @@ class SBSRequestBuilder():
         options ={"markup":markup}
         if query:
             options["queries"]=query
+        
+
         req = requests.get(self.url + "/api/search/v1/documents/"+document_id, params = options, headers = self.headers,verify=self.verify_request)
         return req.json()
 	
@@ -128,10 +130,13 @@ class SBSRequestBuilder():
                 req = requests.get(self.url+"/api/search/v1/document-aggregates/entity",params = options, headers = self.headers,verify=self.verify_request)			
         return req.json()
 
-    def entity_mentions (self,text):
+    def entity_mentions (self,text,entities=None):
         """This endpoint annotates a text string with termite annotations.
         Efectively it works as an API endpoint"""
-        options = {"text":text}
+        if entities:
+            options = {"text":text, "entities":entities}
+        else:
+            options = {"text":text}
         req = requests.get(self.url+"/jobserver/v1/entitymentions", params = options,headers = self.headers,verify=self.verify_request)
         return req.json()
 
@@ -141,4 +146,4 @@ class SBSRequestBuilder():
         headers['Content-type']='application/json' 
         requests.post(self.url+ '/api/search/v1/document-schemas', json = json_body,headers = headers,verify=self.verify_request)
 
-        
+        
\ No newline at end of file
