@@ -11,8 +11,8 @@ generate insights.
 """
 
 
-__author__ = 'SciBite AI'
-__version__ = '0.5.0'
+__author__ = 'SciBite DataScience'
+__version__ = '0.5.4'
 __copyright__ = '(c) 2022, SciBite Ltd'
 __license__ = 'Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License'
 
